matroid_database: Python interface to matroid database
======================================================

Description
-----------

Python interface to matroid database.

This database was retrieved from
<https://www-imai.is.s.u-tokyo.ac.jp/~ymatsu/matroid/index.html>
(Yoshitake Matsumoto, Database of Matroids, 2012; accessed: 2023.12.02).


License
-------

GPL version 3 or later


Upstream Contact
----------------

https://pypi.org/project/matroid-database

https://github.com/gmou3/matroid-database
